<?php
/*
Plugin Name: Entertainrr Events
Plugin URI: http://entertainrr.com/wordpress
Description: The Entertainrr Events Plugin allows Entertainrr clients to embed their ticketshop and other Entertainrr enabled pages to their website seamlessly.
Author: Nuweb Systems Ltd.
Version: 1.0.1
Author URI: http://www.entertainrr.com
License: GPL2

Copyright 2015 Nuweb  (email : support@nuweb.co.uk)

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License, version 2, as
published by the Free Software Foundation.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

/**
 * Define Constants
 */
if (!defined('ENTERTAINRR_PLUGIN_URL')) {
    define('ENTERTAINRR_PLUGIN_URL', plugins_url('/entertainrr-events'));
}
if (!defined('ENTERTAINRR_BASE_URI')) {
    define('ENTERTAINRR_BASE_URI', 'https://admin.entertainrr.com/events/login/');
}

// maps local settings key => api param name
$settings_map = array(
    'entertainrr_width' => 'entertainrr_width',
    'entertainrr_height' => 'entertainrr_height',
    'entertainrr_type' => 'entertainrr_type',
    'entertainrr_style' => 'entertainrr_style',
    'entertainrr_created' => 'entertainrr_created',
);

/**
 * Entertainrr WP Class
 */
class WP_EntertainrrEvents {

    public $entertainrr_options; //Entertainrr options array
    public $entertainrr_settings_page; //Entertainrr settings page
    static $instance; //allows plugin to be called externally without re-constructing

    /**
     * Register hooks with WP Core
     */
    function __construct() {
        global $wpdb;
        self::$instance = $this;

        // init settings array
        $this->entertainrr_options = array(
            'active'                    => true,
            'entertainrr_company_id'      => false,
            'entertainrr_companies'       => false,
            'entertainrr_created'         => false,
            'entertainrr_width'           => false,
            'entertainrr_height'          => false,
            'entertainrr_autoscroll'      => true,
            'entertainrr_region'          => 'uk', //uk, za
            'entertainrr_type'            => 'ticketshop',
            'entertainrr_style'           => 'transition: all 0.3s ease-in-out;margin-left:auto;margin-right:auto;display:block;',
        );

        //entertainrr_i18n
        add_action('init', array(
            $this,
            'entertainrr_i18n'
        ));

        //Write default options to database
        add_option('entertainrr_settings', $this->entertainrr_options);

        //Update options from database
        $this->entertainrr_options = get_option('entertainrr_settings');

        register_deactivation_hook(__FILE__, array(
            $this,
            'entertainrr_deactivate'
        ));

        //Admin settings page actions
        add_action('admin_menu', array(
            $this,
            'entertainrr_add_settings_page'
        ));

        add_action('admin_print_styles', array(
            $this,
            'entertainrr_enqueue_admin'
        ));

        add_action('admin_enqueue_scripts', array(
            $this,
            'entertainrr_localize_config'
        ));

        // action notifies user on admin menu if they don't have a key
        add_action( 'admin_menu', array(
            $this,
            'entertainrr_notify_user_icon'
        ));

        add_action('wp_ajax_entertainrr_update_option', array(
            $this,
            'entertainrr_update_option'
        ));
        add_action('wp_ajax_entertainrr_save_account', array(
            $this,
            'entertainrr_save_account',
        ));

        add_action('wp_ajax_entertainrr_disconnect_account', array(
            $this,
            'entertainrr_disconnect_account',
        ));

        add_action('admin_head', array(
            $this,
            'entertainrr_embed_page_button'
        ));

        add_action('admin_enqueue_scripts', array(
            $this,
            'entertainrr_embed_page_button_css'
        ));

        add_shortcode( 'entertainrr', array(
            $this,
            'entertainrr_shortcode'
        ));
 
    }

    function entertainrr_shortcode($atts) {
        $atts = shortcode_atts(array(
         'width'        => false,
         'height'       => false,
         'style'        => false,
         'url'          => false,
         'type'         => false,
         'autoscroll'   => false,
        ), $atts, 'entertainrr');


        $width = $atts['width'];
        empty($width) && $width = $this->entertainrr_get_value_entertainrr_width();
        empty($width) && $width = '100%';

        $height = $atts['height'];
        empty($height) && $height = $this->entertainrr_get_value_entertainrr_height();

        $style = $atts['style'];
        empty($style) && $style = $this->entertainrr_get_value_entertainrr_style();

        $autoscroll = $atts['autoscroll'];
        empty($autoscroll) && $autoscroll = $this->entertainrr_options['entertainrr_autoscroll'];
        $autoscroll = $this->entertainrr_get_validated_value('autoscroll', $autoscroll);
        if ($autoscroll === 'false' || $autoscroll == 0 || $autoscroll == '0') {
            $autoscroll = false;
        }

        $url = $atts['url'];
        empty($url) && $url = $this->get_value_entertainrr_url($atts['type']);
        $url = $this->entertainrr_format_url($url);
        if (!$url) return '';

        $domain = $this->entertainrr_get_domain_from_url($url);

        $id = entertainrr_random_token(10);

        $return = '<iframe id="entertainrr-frame-'.esc_attr($id).'" class="entertainrr-frame" width="'.esc_attr($width).'"';
        $script = '';
        $http   = 'http://'.$domain;
        $https  = 'https://'.$domain;
        if ($height === false || $height == '') {
            $return .=' scrolling="no" height="1200px"';
            $script .= '<script type="text/javascript">var _nu_iframe=document.getElementById("entertainrr-frame-'.$id.'");function setDialogSize(a){window.onresize&&window.onresize();a.origin.match(/^http(s)?:\/\/(.*).entertainrr.(com|co.za)(\/)?$/i)!==null?_nu_iframe.style.height=a.data+"px":(_nu_iframe.style.height=Math.min(900,Math.max(getHeight(),450))+"px",_nu_iframe.style.overflowY="scroll",_nu_iframe.setAttribute("scrolling","yes"))}window.addEventListener("message",setDialogSize,!1);_nu_iframe.addEventListener("load",nuScrollToiFrame);';
            if ($autoscroll) {
                $script .= 'function nuScrollToiFrame(){var a=0,b=_nu_iframe;if(b.offsetParent){do a+=b.offsetTop;while(b=b.offsetParent)}else a=_nu_iframe.offsetTop;"undefined"==typeof jQuery?window.scrollTo(0,a):jQuery("html, body").animate({scrollTop:a},800)}';
            }
            $script .= 'function getHeight(){return window.innerHeight||document.documentElement&&document.documentElement.clientHeight||document.body.clientHeight};</script>';
        } else {
            $return .=' height="'.esc_attr($height).'"';
        }
        $return .= ' frameborder="0" allowtransparency="yes" src="'.esc_url($url).'" style="'.esc_attr($style).'"></iframe>'.$script;

        return $return;
    }

    function entertainrr_embed_page_button_css() {
        wp_enqueue_style('entertainrr_button_css', plugins_url('/css/editor-plugin.min.css', __FILE__));
    }

    function entertainrr_embed_page_button() {
        global $typenow;
        // check user permissions
        if ( !current_user_can('edit_posts') && !current_user_can('edit_pages') ) {
            return;
        }
        
        // verify the post type
        if (!in_array($typenow, array( 'post', 'page' )))
            return;
        
        // check if WYSIWYG is enabled
        if ( get_user_option('rich_editing') == 'true') {
            add_filter('mce_buttons', array($this, 'entertainrr_register_embed_nt_button'));
            add_filter('mce_external_plugins', array($this, 'entertainrr_add_tinymce_plugin'));
        }
    }

    function entertainrr_add_tinymce_plugin($plugin_array) {
        $plugin_array['entertainrr_button'] = plugins_url( '/js/editor-plugin.min.js', __FILE__ ); // CHANGE THE BUTTON SCRIPT HERE
        return $plugin_array;
    }

    function entertainrr_register_embed_nt_button($buttons) {
       array_push($buttons, "entertainrr_button");
       return $buttons;
    }

    /**
    * receives Entertainrr account data from connection request
    **/
    function entertainrr_save_account() {
        // not validating the analytics_key for security.
        // analytics calls will just fail if it's invalid.
        //@todo If API key needed?
        if(isset($_POST) && !empty($_POST)) {
            $company_id         = $this->entertainrr_get_validated_value('company_id', $_POST['company_id']);
            $companies          = $this->entertainrr_get_validated_value('companies', $_POST['companies']);
            $entertainrr_region   = $this->entertainrr_get_validated_value('region', $_POST['region']);

            $this->entertainrr_save_option('entertainrr_region', $entertainrr_region);
            $this->entertainrr_save_option('entertainrr_company_id', $company_id);
            $this->entertainrr_save_option('entertainrr_companies', json_encode($companies));
            $this->entertainrr_save_option('entertainrr_created', date('Y-m-d H:m:i'));
            $this->entertainrr_save_option('entertainrr_autoscroll', 1);

            // better than returning some ambiguous boolean type
            echo 'true';
            wp_die();
        }
        echo 'false';
        wp_die();
    }

    /**
    * Disconnects already connected Entertainrr account and removes its data
    **/
    function entertainrr_disconnect_account() {
        // not validating the analytics_key for security.
        // analytics calls will just fail if it's invalid.
        //@todo If API key needed?
        $this->entertainrr_save_option('entertainrr_company_id', false);
        $this->entertainrr_save_option('entertainrr_companies', false);
        $this->entertainrr_save_option('entertainrr_created', false);

        // better than returning some ambiguous boolean type
        echo 'true';
        wp_die();
    }

    /**
    * handles request from frontend to update a card setting
    **/
    function entertainrr_update_option() {
        if(!isset($_POST) || empty($_POST)) {
          echo 'ajax-error';
          wp_die();
        }

        $key = sanitize_key($_POST['key']);

        switch($key) {
            case 'entertainrr_width':
            case 'entertainrr_height':
                $this->entertainrr_save_option($key, $this->entertainrr_handle_width_input($_POST['value']));
                break;
            case 'entertainrr_company_id':
            case 'entertainrr_style':
            case 'entertainrr_autoscroll':
                // access to the $_POST from the ajax call data object
                $this->entertainrr_save_option($key, $this->entertainrr_get_validated_value($key, $_POST['value']));
                break;
        }

        wp_die();
    }

    /**
     * Load plugin translation
     */
    function entertainrr_i18n() {
        load_plugin_textdomain('entertainrr', false, dirname(plugin_basename(__FILE__)) . '/lang/');
    }

    /**
     * Deactivation Hook
     **/
    function entertainrr_deactivate() {
        delete_option('entertainrr_settings');
    }


    /**
    * Warns user if setup is not complete
    **/
    function entertainrr_notify_user_icon() {
        if( !empty($this->entertainrr_options['key'])) {
            return;
        }

        global $menu;
        if ( !$this->entertainrr_valid_key() ) {
            foreach ( $menu as $key => $value ) {
                if ($menu[$key][2] == 'entertainrr-events') {
                    // accesses the menu item html
                    $menu[$key][0] .= ' <span class="update-plugins count-1">'.
                      '<span class="plugin-count"'.
                      'title="'.esc_html__('Please log in to your Entertainrr account to use this plugin', 'entertainrr') . '">'.
                      '!</span></span>';
                    return;
                }
            }
        }
    }

    /**
     * Adds toplevel Entertainrr settings page
     **/
    function entertainrr_add_settings_page() {
        $icon = 'dashicons-admin-generic';
        if( version_compare( $GLOBALS['wp_version'], '4.1', '>' ) ) {
           $icon = 'none';
        }

        $this->entertainrr_settings_page = add_menu_page('Entertainrr Events', 'Entertainrr Events', 'activate_plugins', 'entertainrr-events', array(
                $this,
                'entertainrr_settings_page'
            ), $icon);
    }


    /**
     * Enqueue styles/scripts for Entertainrr page(s) only
     **/
    function entertainrr_enqueue_admin() {
        $screen = get_current_screen();
        if ($screen->id == $this->entertainrr_settings_page) {
            wp_enqueue_style('dashicons');
            wp_enqueue_style('entertainrr_admin_styles', ENTERTAINRR_PLUGIN_URL . '/css/entertainrr-admin.min.css');
        }
        return;
    }

    /**
    *  Localizes the configuration settings for the user, making ENTERTAINRR_CONFIG available
    *  prior to loading entertainrr.js
    **/
    function entertainrr_localize_config() {
        global $settings_map;

        $ajax_url = admin_url( 'admin-ajax.php', 'relative' );

        $current = array();
        foreach ($settings_map as $setting => $api_param) {
            if(isset($this->entertainrr_options[$setting])) {
                if( is_bool($this->entertainrr_options[$setting])) {
                    $current[$setting] = $this->entertainrr_options[$setting] ? '1' : '0';
                } else {
                    $current[$setting] = $this->entertainrr_options[$setting];
                }
            }
        }

        $entertainrr_config = array(
            'ajaxurl' => $ajax_url,
            'created' => $current['created'],
            'current' => $current,
        );

        wp_register_script('entertainrr_admin_scripts', ENTERTAINRR_PLUGIN_URL . '/js/entertainrr.min.js', array(
                'jquery'
            ), '1.0', true);
        wp_localize_script('entertainrr_admin_scripts', 'ENTERTAINRR_CONFIG', $entertainrr_config);
        wp_localize_script('entertainrr_admin_scripts', 'entertainrr_objectL10n', array(
            'entertainrr_wysiwyg_embed_button'           => esc_html__('Embed Entertainrr Box Office', 'entertainrr'),
            'entertainrr_connect_error_text'             => esc_html__('There was a problem connecting to your Entertainrr account. Please contact support@entertainrr.com', 'entertainrr'),
            'entertainrr_connect_login_error_warning'    => esc_html__("Log in to your Entertainrr account", 'entertainrr'),
            'entertainrr_connect_redirect_button_text'   => esc_html__("REDIRECTING TO ENTERTAINRR...", 'entertainrr'),
            'entertainrr_connect_connect_button_text'    => esc_html__("CONNECTING...", 'entertainrr'),
            'entertainrr_disconnect_warning'             => esc_html__('If you disconnect your account, all of your embedded Entertainrr pages will be hidden to your customers on your site until you connect to a new account. Are you sure you want to disconnect?', 'entertainrr'),
            'entertainrr_disconnect_error_text'          => esc_html__('There was a problem disconnecting your Entertainrr account. Please contact support@entertainrr.com', 'entertainrr'),
        ));
        wp_enqueue_script('entertainrr_admin_scripts');
    }

    /**
    * update entertainrr_options with a given key: value pair
    **/
    function entertainrr_save_option($key, $value) {
       $this->entertainrr_options[$key] = $value;
       update_option('entertainrr_settings', $this->entertainrr_options);
       $this->entertainrr_options = get_option('entertainrr_settings');
    }

    /**
    * removes a setting
    **/
    function entertainrr_delete_option($key) {
        unset($this->entertainrr_options[$key]);
        update_option('entertainrr_settings', $this->entertainrr_options);
        $this->entertainrr_options = get_option('entertainrr_settings');
    }


    /**
    * handles 'max width' input for card defaults
    * returns the string corresponding to the correct cards_width
    * card parameter
    **/
    function entertainrr_handle_width_input($input) {
        // width can be '%' or 'px'
        // first check if '100%',
        $percent = $this->entertainrr_int_before_substring($input, '%');
        if ($percent != 0 && $percent <= 100) {
            return $percent . '%';
        }

        // try for a value like 300px (platform can only handle >200px?)
        $pixels = $this->entertainrr_int_before_substring($input, 'px');
        if ($pixels > 0) {
            return max($pixels, 200);
        }

        // try solitary int value.
        $int = intval($input);
        if ($int > 0) {
            return max($int, 200);
        }

        return false;
    }


    /**
    * returns valid integer (not inclusive of 0, which indicates failure)
    * preceding a given token $substring.
    * given '100%', '%' returns 100
    * given 'asdf', '%', returns 0
    **/
    function entertainrr_int_before_substring($whole, $substring) {
        $pos = strpos($whole, $substring);
        if($pos != false) {
            $preceding = substr($whole, 0, $pos);
            return $percent = intval($preceding);
        }
    }

    /**
    * setup check
    **/
    function entertainrr_valid_key() {
        if (empty($this->entertainrr_options['entertainrr_created'])) {
          return false;
        }

        return true;
    }

    /////////////////////////// BEGIN TEMPLATE FUNCTIONS FOR FORM LOGIC


    /**
    * returns max width setting as a css value
    **/
    function entertainrr_get_value_entertainrr_width() {
        $value = false;
        if(isset($this->entertainrr_options['entertainrr_width']) && strlen($this->entertainrr_options['entertainrr_width']) > 0) {
          $width = $this->entertainrr_get_validated_value('width', $this->entertainrr_options['entertainrr_width']);
          return $width;
        }
    }

    /**
    * returns max height setting as a css value
    **/
    function entertainrr_get_value_entertainrr_height() {
        $value = false;
        if(isset($this->entertainrr_options['entertainrr_height']) && strlen($this->entertainrr_options['entertainrr_height']) > 0) {
          $height = $this->entertainrr_get_validated_value('height', $this->entertainrr_options['entertainrr_height']);
          return $height;
        }
    }

    /**
    * returns style setting as a html value attr
    **/
    function entertainrr_get_value_entertainrr_style() {
        $value = $this->entertainrr_get_validated_value('style', empty($this->entertainrr_options['entertainrr_style']) || !$this->entertainrr_options['entertainrr_style'] ? 'transition: all 0.3s ease-in-out;margin-left:auto;margin-right:auto;display:block;' : $this->entertainrr_options['entertainrr_style']);
        return $value;
    }

    function entertainrr_get_validated_value($field = false, $value = false){
        if ($field === false || $value === false) { return false; }

        $field = sanitize_key(strpos($field, 'entertainrr_') === 0 ? substr($field, strlen('entertainrr_')) : $field);
        $value = is_bool($value) || is_object($value) || is_array($value) ? $value : sanitize_text_field($value);

        if (($field == 'company') && (is_object($value) || is_array($value))) {
            foreach ($value as $key => $val) {
                if (is_string($key) && stripos($key, 'url') !== false && stripos($val, '://') === false) {
                    $val = 'http://' . $val;
                }
                if (is_object($value)) {
                    $value->{$key} = $this->entertainrr_get_validated_value($key, $val);
                } else {
                    $value[$key] = $this->entertainrr_get_validated_value($key, $val);
                }
            }
            return $value;
        }

        switch ($field):
            case 'company_id':
                return (intval($value) > 0) ? intval($value) : false;
                break;

            case 'companies':
                //If for some reason we would get a single companies data, not a list of companies, put them in an array
                if (!empty($value['company_id'])) {
                    $value = array($value);
                }
                if (!is_array($value)) { return false; }
                foreach ($value as $key => $val) {
                    $value[$key] = $this->entertainrr_get_validated_value('company', $val);
                }
                return $value;
                break;

            case 'style':
                $value = sanitize_text_field(str_replace(array('\'', '"'), '', $value));
                return empty($value) ? false : $value;
                break;

            case 'company_name':
                return sanitize_text_field($value);
                break;

            case 'url':
            case 'ticketshop_url':
            case 'employees_url':
            case 'reps_url':
            case 'shop_url':
                return esc_url_raw(filter_var($value, FILTER_VALIDATE_URL));
                break;

            case 'width':
            case 'height':
                if (strpos($value, '%') !== false) {
                    return $value;
                } else if (intval($value) > 0) {
                    return intval($value) . "px";
                } else if ($value == 'auto') {
                    return 'auto';
                }
                return false;
                break;

            case 'created':
                return date('Y-m-d H:m:i', strtotime($value));
            case 'autoscroll':
                return $value ? 1 : 0;
                break;

            case 'region':
                return in_array($value, array('com')) ? $value : 'com';
                break;

            case 'type':
                return in_array($value, array('ticketshop', 'employees', 'reps', 'shop')) ? $value : 'ticketshop';
                break;
        endswitch;

        return false;
    }

    /**
    * returns max_width setting as a html value attr
    **/
    function get_value_entertainrr_url($type = false) {
        $company = $this->entertainrr_get_company();
        if (!$company) return false;
        $value = $company->ticketshop_url;
        switch ($type) {
            case 'employees':
                $value = $company->employees_url;
                break;
            case 'reps':
                $value = $company->reps_url;
                break;
            case 'shop':
                $value = $company->shop_url;
                break;
        }
        return $value;
    }


    /**
    * returns admin's URL
    **/
    function get_entertainrr_admin_url() {
        return 'https://admin.entertainrr.com';
    }

    function entertainrr_format_url($url = false) {
        $url = $this->entertainrr_get_validated_value('url', $url);
        if (!$url) { return false; }

        if (strpos($url, 'http') === 0) {
            $url = str_replace(
                array('http://', 'https://'), 
                array('//', '//'),
                $url
            );
        } elseif (strpos($url, 'www') === 0) {
            $url = '//'.$url;
        } elseif (strpos($url, '//') === 0) {
            //Good as it is!
        } else {
            $url = '//'.$url;
        }
        return $url;
    }

    function entertainrr_get_domain_from_url($url = false) {
        if (!$url) { return false; }

        $url = parse_url('http:'.$url);

        return $url['host'];
    }

    /**
    * returns array of companies
    **/
    function entertainrr_get_companies() {
        return $this->entertainrr_get_validated_value('companies', json_decode($this->entertainrr_options['entertainrr_companies']));
    }

    /**
    * returns current company
    **/
    function entertainrr_get_company() {
        $companies = $this->entertainrr_get_validated_value('companies', json_decode($this->entertainrr_options['entertainrr_companies']));
        $id = $this->entertainrr_get_validated_value('company_id', $this->entertainrr_options['entertainrr_company_id']);

        if ($companies !== false && $id !== false) {
            if (!$id && count($companies) == 1) {
                $id = $companies[0]['company_id'];
            }
            $this->entertainrr_save_option('entertainrr_company_id', $id);
            
            if ($id) {
                $selected = array_filter($companies, function($obj) use ($id) {
                    if (isset($obj->company_id) && $obj->company_id == $id) {
                        return true;
                    }
                    return false;
                });
                if ($selected && count($selected) == 1) {
                    return reset($selected);
                }
            }
        }
        return false;
    }


    /**
    * Setup content
    **/
    function entertainrr_get_setup_content($company, $companies) {
        ?><div class="entertainrr-highlight">
            <h1><?php _e('Congratulations!', 'entertainrr'); ?></h1>
            <h2>
                <?php printf( 
                    esc_html__("You've successfully installed your %s ticketshop to WordPress!", 'entertainrr'), 
                    ('<a class="entertainrr-link" target="_blank" href="http:'. $this->entertainrr_format_url($this->get_value_entertainrr_url()) .'">'.
                        stripslashes($company->company_name).
                    '</a>')); ?>
            </h2>
        </div>
        <div class="entertainrr-content">
            <div class="entertainrr-first-steps">
                <h2><?php _e('How to use it', 'entertainrr'); ?></h2>
                <ol>
                    <li class="clearfix">
                        <img src="<?php echo ENTERTAINRR_PLUGIN_URL . "/img/howtostep1@2x.png" ?>">
                        <h3><?php _e('Add it to a page', 'entertainrr'); ?></h3>
                        <p>
                            <?php _e("You can add your ticketshop to any page just with a click. Just add or edit a page, or a post, and click on the Entertainrr button in the editor.", 'entertainrr'); ?>
                        </p>
                    </li>
                    <li class="clearfix">
                        <img src="<?php echo ENTERTAINRR_PLUGIN_URL . "/img/howtostep2@2x.png" ?>">
                        <h3><?php _e('Any questions?', 'entertainrr'); ?></h3>
                        <p>
                            <?php printf( 
                                esc_html__("For more information about the setup or installation please %scheck out our tutorial%s.", 'entertainrr'), 
                                ('<a target="_blank" href="http://entertainrr.com/wordpress">'),
                                '</a>'); ?>
                        </p>
                    </li>
                </ol>
            </div>
        </div>

        <div class="entertainrr-content">
            <a href=".entertainrr-advanced-settings-toggles" class="entertainrr-advanced-settings-toggles entertainrr-toggle-content entertainrr-toggle-active" data-entertainrr-target-toggle=""><?php _e('Show advanced settings...', 'entertainrr'); ?></a>
            <a href=".entertainrr-advanced-settings-toggles" class="entertainrr-advanced-settings-toggles entertainrr-toggle-content" data-entertainrr-target-toggle=""><?php _e('Hide advanced settings...', 'entertainrr'); ?></a>
        </div>

        <div class="entertainrr-content">
            <div class="entertainrr-advanced-settings-toggles entertainrr-toggle-content" id="entertainrr-tab-settings">
              <div class="entertainrr-panel">
                  <h3 class="entertainrr-panel-title">
                    <?php _e('Advanced Settings', 'entertainrr'); ?>
                </h3>
                  <div class="entertainrr-panel-status">
                    <p>
                        <?php _e('Changing these settings will modify all embedded Entertainrr pages on your site. All settings are saved automatically.', 'entertainrr');?> <span id="entertainrr-settings-saved" class="entertainrr-settings-saved entertainrr-settings-notification"><?php _e('Settings updated successfully', 'entertainrr'); ?></span>
                   </p>
                  </div>
                  <div class="entertainrr-panel-body">
                    <div class="advanced-selections">
                      <ul>
                        <li>
                          <div>
                            <label><?php _e('Width', 'entertainrr'); ?></label>
                            <input data-entertainrr-input-autosave="" id='entertainrr-width' type="text" name="entertainrr_width" placeholder="<?php _e('Responsive if left blank', 'entertainrr'); ?>"
                              value="<?php esc_html($this->entertainrr_get_value_entertainrr_width()); ?>" />
                              <p><i><?php _e('Example: 400px or 80%.', 'entertainrr'); ?></i></p>
                          </div>
                        </li>
                        <li>
                          <div>
                            <label><?php _e('Height', 'entertainrr'); ?></label>
                            <input data-entertainrr-input-autosave="" id='entertainrr-height' type="text" name="entertainrr_height" placeholder="<?php _e('If left blank, height changes depending on the content.', 'entertainrr'); ?>" 
                              value="<?php esc_html($this->entertainrr_get_value_entertainrr_height()); ?>" />
                              <p><i><?php _e('Example: 400px or 80%. If left blank height changes depending on content.', 'entertainrr'); ?></i></p>
                          </div>
                        </li>
                        <li>
                          <div>
                            <label>
                                <input data-entertainrr-checkbox-autosave="" value="1" id='entertainrr-entertainrr_autoscroll' type="checkbox" name="entertainrr_autoscroll" <?php $this->entertainrr_get_validated_value('autoscroll', $this->entertainrr_options['entertainrr_autoscroll']) ? ' checked="checked"' : ''?> > 
                                <?php _e('Autoscroll', 'entertainrr'); ?>
                            </label>
                              <p>
                                <i>
                                    <?php _e('If height is left blank the Entertainrr block changes its height depending on the content.', 'entertainrr'); ?><br>
                                    <?php _e('On page load, and navigating between pages, your site would autoscroll to the top of the Entertainrr page for easier navigation for customers.', 'entertainrr'); ?>
                                </i>
                            </p>
                          </div>
                        </li>
                        <li>
                          <div>
                            <label><?php _e('Frame CSS', 'entertainrr'); ?></label>
                            <textarea data-entertainrr-input-autosave="" id='entertainrr-style' type="text" name="entertainrr_style" style="height:107px;"><?=esc_textarea($this->entertainrr_get_value_entertainrr_style()); ?></textarea>
                              <p><i><?php _e('Default value: transition: all 0.3s ease-in-out;margin-left:auto;margin-right:auto;display:block;', 'entertainrr'); ?></i></p>
                          </div>
                        </li>
                        <?php if ($company): ?>
                            <li>
                              <div>
                                <label><?php _e('Change account:', 'entertainrr'); ?></label>
                                <select name="entertainrr_company_id"<?= (count($companies) == 1) ? ' readonly="readonly"' : ''?>  data-entertainrr-input-autosave="">
                                <?php
                                    foreach ($companies as $item) {
                                        echo '<option value="'.$item->company_id.'"';
                                        echo ($item->company_id == $company->company_id) ? ' selected="selected"' : '';
                                        echo '>'.stripslashes($item->company_name).'</option>';
                                    }
                                ?>
                                </select><br>
                                <p><i><a href="#" data-disconnect-entertainrr=""><?php _e('Disconnect Entertainrr account', 'entertainrr') ?></a></i></p>
                              </div>
                            </li>
                        <?php endif; ?>
                      </ul>
                    </div>
                  </div>
                </div>
            </div> <!-- END 'Options' Section -->
        </div><?php 
    }
    /////////////////////////// END TEMPLATE FUNCTIONS FOR FORM LOGIC

    /**
     * The Admin Page
     **/
    function entertainrr_settings_page() {
        global $wpdb;
        ######## BEGIN FORM HTML #########
        ?>
          <div class="entertainrr-wrap">
            <div class="entertainrr-ui">
              <div class="entertainrr-input-wrapper">
                <?php
                
                if( $this->entertainrr_valid_key() ) { ?>

                <form id="entertainrr_key_form" method="POST" action="">
                    <div class="entertainrr-ui-header-wrapper">
                      <div class="entertainrr-ui-header">
                        <div class="entertainrr-ui-logo"><?php
                          _e('Entertainrr Events', 'entertainrr');
                          ?></div>
                      </div>
                    </div>

                    <div class="entertainrr_key_form entertainrr-ui-key-form">
                        <div id="entertainrr-tab-main">
                            <?php
                                $companies = $this->entertainrr_get_companies();
                                $company = $this->entertainrr_get_company();

                                if ($company) {
                                    echo $this->entertainrr_get_setup_content($company, $companies);
                                } elseif ((count($companies) == 1) || count($companies) == 0) {
                                    ?><div class="entertainrr-content">
                                        <div class="entertainrr-panel">
                                            <h3 class="entertainrr-panel-title"><?php _e('Setup incomplete', 'entertainrr'); ?></h3>
                                            <div class="entertainrr-panel-body">
                                                <span class="entertainrr-settings-notification entertainrr-settings-error">
                                                    <?php _e('No companies found!', 'entertainrr'); ?> <a href="#" data-disconnect-entertainrr="">
                                                    <?php _e('Please reconnect your Entertainrr account', 'entertainrr'); ?></a>
                                                </span>
                                                <br><br><?php _e('If the problem persists please send an email to <a href="mailto:info@entertainrr.com">info@entertainrr.com</a>', 'entertainrr'); ?>
                                            </div>
                                        </div>
                                    </div><?php 
                                } elseif (count($companies) > 1) {
                                    ?><div class="entertainrr-content">
                                        <div class="entertainrr-panel">
                                            <h3 class="entertainrr-panel-title"><?php _e('Choose your company', 'entertainrr'); ?></h3>
                                            <div class="entertainrr-panel-body">
                                                <ul>
                                                    <li>
                                                        <label>
                                                            <?php _e('Please select the company which you\'ll want to embed in your site:', 'entertainrr'); ?>
                                                        </label>
                                                        <select name="entertainrr_company_id" data-entertainrr-input-autosave="">
                                                            <option value=""></option>
                                                        <?php
                                                            foreach ($companies as $item) {
                                                                echo '<option value="'.$item->company_id.'">'.stripslashes($item->company_name).'</option>';
                                                            }
                                                        ?>
                                                        </select>
                                                    </li>
                                                </ul>
                                            </div>
                                        </div>
                                    </div><?php
                                }
                            ?>
                        </div>
                    </div>
                  </form>
                <?php  // ELSE: Key is not entered
              } else {  ?>
                  <!-- MODAL FOR NEW ACCOUNTS -->
                <div class="entertainrr-ui">
                <div class="entertainrr-ui-header-wrapper">
                  <div class="entertainrr-ui-header">
                    <div class="entertainrr-ui-logo"><?php
                      _e('Entertainrr Events', 'entertainrr');
                      ?></div>
                  </div>
                </div>
                  <div class="entertainrr-ui-key-wrap entertainrr-new-user-modal">
                    <div class="entertainrr_key_form entertainrr-ui-key-form">
                        <div class="entertainrr-content">
                          <div class="welcome-page-body">
                            <!-- HERO TEXT -->
                            <h1><?php _e('Follow the instructions to set up the plugin', 'entertainrr'); ?></h1>
                            <h2 class="entertainrr-subtitle">
                                <?php _e("The Entertainrr Events Plugin allows Entertainrr clients to embed your ticketshop and other Entertainrr enabled pages to your website seamlessly", 'entertainrr'); ?>
                            </h2>

                            <section class="entertainrr-region-selector">
                                <label><?php _e('Select your login website', 'entertainrr'); ?></label>
                                <select data-change-region="">
                                    <option></option>
                                    <option value="com" selected="selected">
                                        <?php _e('Entertainrr.com', 'entertainrr'); ?>
                                    </option>
                                </select>
                            </section>

                            <section id="entertainrr-connect-account">
                              <!-- Create a entertainrr account button -->
                            <p>
                                <?php _e("Already have a Entertainrr account?", "entertainrr"); ?>
                            </p>
                              <button id="entertainrr-connect-button" class="entertainrr-button entertainrr-button-long" data-button-text="<?php _e("LOG IN WITH YOUR %ENTERTAINRR% ACCOUNT", "entertainrr"); ?>">
                                <div class="inner-connect-button">
                                  <span class="inner-button-span">
                                    <img id="connect-btn-img" src=<?php echo ENTERTAINRR_PLUGIN_URL . "/img/nu_logo@2x.png" ?> height="60">
                                  </span>
                                  <span class="inner-button-span" data-button-text-target="">
                                    <?php _e("LOG IN WITH YOUR %ENTERTAINRR% ACCOUNT", "entertainrr"); ?>
                                  </span>
                                </div>
                              </button>
                              <div class="entertainrr-create-account-btn-wrap">
                                <p>
                                    <?php _e("Don't Have An Account?", "entertainrr"); ?> <a id='create-account-btn' href="http://events.entertainrr.com/get-started/" class="" target="_blank">
                                        <?php _e('Get started here', 'entertainrr')?>
                                    </a>
                                </p>
                              </div>
                            </section>

                            <section>
                              <div id="entertainrr-connect-failed-refresh">
                              <p> <?php _e("You may need to refresh the page after connecting", "entertainrr"); ?></p>
                              </div>
                            </section>
                           </div>
                        </div>
                     </div>
                   </div>
                </div>
              <?php } // END if/else for new/existing account
              ?>
                <div id="footer">
                  <footer class="entertainrr-footer">
                    &copy; <?php echo date('Y') . ' '; _e('All Rights Reserved', 'entertainrr'); ?>, Nuweb Systems Ltd.
                  </footer>
                </div>
            </div>
        </div>
    </div><?php
    } // END settings page function
} // END WP_EntertainrrEvents class

function entertainrr_random_token($length = 32){
    if (!isset($length) || intval($length) <= 8) {
        $length = 32;
    }
    if (function_exists('random_bytes')) {
        return bin2hex(random_bytes($length));
    }
    if (function_exists('mcrypt_create_iv')) {
        return bin2hex(mcrypt_create_iv($length, MCRYPT_DEV_URANDOM));
    }
    if (function_exists('openssl_random_pseudo_bytes')) {
        return bin2hex(openssl_random_pseudo_bytes($length));
    }
}

//Instantiate a Global WP_NutiketsEvents
$WP_EntertainrrEvents = new WP_EntertainrrEvents();
